@@ -41,9 +41,14 @@
 /* Defines if you have OpenGL installed */
 #undef HAVE_GL
 
+/* Defines if you have libz installed */
+#undef HAVE_LIBZ
+
 /* Defines if you have libjpeg installed */
 #undef HAVE_LIBJPEG
 
+/* Defines if you have libpng installed */
+#undef HAVE_LIBPNG
 
 #define HAVE_MEDIATOOL 1
 
