@@ -1,6 +1,6 @@
 /*
  *   kmoon - a moon phase indicator
- *   $Id: kmoon.cpp,v 1.2 1998/12/13 20:04:19 ettrich Exp $
+ *   $Id: kmoon.cpp,v 1.15 2000/02/04 10:19:19 kulow Exp $
  *   Copyright (C) 1998  Stephan Kulow
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -26,11 +26,16 @@
 #include <qwmatrix.h>
 #include <qbitmap.h>
 #include <qtooltip.h>
-#include <kmsgbox.h>
+#include <kmessagebox.h>
+#include <kaboutdata.h>
 #include <qimage.h>
 #include <stdlib.h>
-
-QList<QImage> *MoonWidget::moons = 0;
+#include <klocale.h>
+#include <qpopupmenu.h>
+#include <kglobal.h>
+#include <kstddirs.h>
+#include <kcmdlineargs.h>
+#include "version.h"
 
 double moonphasebylunation(int lun, int phi);
 time_t JDtoDate(double jd, struct tm *event_date);
@@ -41,8 +46,6 @@ MoonWidget::MoonWidget(QWidget *parent, const char *name)
     struct tm * t;
     time_t clock;
 
-    if (!moons)
-	loadMoons();
     counter = -1;
     old_w = old_h = old_counter = -1;
     startTimer(100000);
@@ -54,9 +57,9 @@ MoonWidget::MoonWidget(QWidget *parent, const char *name)
     KWM::setDockWindow(winId());
     kapp->setTopWidget(new QWidget());
     popup = new QPopupMenu();
-    popup->insertItem(i18n("About"));
+    id_about = popup->insertItem(i18n("About"));
     popup->insertSeparator();
-    popup->insertItem(i18n("Quit"));
+    id_quit = popup->insertItem(i18n("Quit"));
 
     connect(popup, SIGNAL(activated(int)), SLOT(reactOn(int)));
 
@@ -64,10 +67,11 @@ MoonWidget::MoonWidget(QWidget *parent, const char *name)
 
 void MoonWidget::reactOn(int index)
 {
-    if (index == 0)
-	showAbout();
-    if (index == 2)
-	kapp->quit();
+  if (index == id_about)
+    showAbout();
+
+  if (index == id_quit)
+    kapp->quit();
 }
 
 void MoonWidget::calcStatus( time_t time )
@@ -91,32 +95,27 @@ void MoonWidget::calcStatus( time_t time )
 	counter -= 29;
 }
 
-void MoonWidget::loadMoons()
+QImage MoonWidget::loadMoon(int index)
 {
-    moons = new QList<QImage>();
-
-    for (int i = 1; i <= 29; i++) {
-	QString name;
-	name.sprintf("%s/kmoon/pics/moon%d.gif",
-		     KApplication::kde_datadir().data(),
-		     i);
-	QImage *p = new QImage(name);
-	moons->append(p);
-    }
-	
+  QString filename = QString("kmoon/pics/moon%1.png").arg(index);
+  filename = locate("data", filename);
+  return QImage(filename);
 }
 
+const char *description = I18N_NOOP("Moon Phase Indicator for KDE");
+
 void MoonWidget::showAbout()
 {
-    KMsgBox::message(0, i18n("About Moon Phase Indicator"),
-		     i18n("Moon Phase Indicator for KDE\n\n"
-			  "Written by Stephan Kulow <coolo@kde.org>\n"
-			  "\n"
-			  "Lunar code by Chris Osburn "
-			  "<chris@speakeasy.org>\n"
-			  "\n"
-			  "Moon graphics by Tim Beauchamp "
-			  "<timb@googol.com>"));
+    KMessageBox::about(0,
+		       i18n(description) + QString::fromLatin1("\n\n") + 
+		       i18n("Written by Stephan Kulow <coolo@kde.org>\n"
+			    "\n"
+			    "Lunar code by Chris Osburn "
+			    "<chris@speakeasy.org>\n"
+			    "\n"
+			    "Moon graphics by Tim Beauchamp "
+			    "<timb@googol.com>"),
+		       i18n("About Moon Phase Indicator"));
 }
 
 void MoonWidget::timerEvent( QTimerEvent * )
@@ -150,14 +149,14 @@ void MoonWidget::renderGraphic()
     old_w = width();
     old_h = height();
     QPixmap t;
-    t.convertFromImage(*moons->at(counter), AvoidDither);
+    t.convertFromImage(loadMoon(counter), AvoidDither);
     QWMatrix m;
     m.scale(float(width()) / t.width(),
 	    float(height()) / t.height());
     QImage im = t.xForm(m).convertToImage().convertDepth(8, AvoidDither);
 
     QColor col1 = yellow;
-    QColor col2 = kapp->backgroundColor;
+    QColor col2 = QApplication::palette().normal().background();
 
     int r1 = col1.red(), r2 = col2.red();
     int g1 = col1.green(), g2 = col2.green();
@@ -172,7 +171,7 @@ void MoonWidget::renderGraphic()
     pixmap.convertFromImage(im, AvoidDither);
 
     QToolTip::remove(this);
-    tooltip.sprintf(i18n("Moon is %d days old."), counter + 1);
+    tooltip = i18n("Moon is %1 days old.").arg(counter + 1);
     QToolTip::add(this, tooltip);
 }
 
@@ -187,15 +186,35 @@ void MoonWidget::mousePressEvent( QMouseEvent *e)
     }
 }
 
+static KCmdLineOptions options[] =
+{
+    { "o", 0, 0 },
+    { "offset <days>", I18N_NOOP("Set the moon some days off"), "0" },
+    { 0, 0, 0}
+};
+
 int main( int argc, char **argv)
 {
-    KApplication a(argc, argv);
+    KAboutData aboutData( "kmoon", I18N_NOOP("KMoon"),
+        version, description, KAboutData::License_GPL,
+        "(c) 1998, Stephan Kulow");
+    aboutData.addAuthor("Stephan Kulow",0, "coolo@kde.org");
+    KCmdLineArgs::init( argc, argv, &aboutData );
+    KCmdLineArgs::addCmdLineOptions( options );
+
+    KApplication a;
     MoonWidget *moon = new MoonWidget();
+#warning fix session management
+#if 0
     kapp->enableSessionManagement( TRUE );
+#endif
     kapp->setTopWidget(new QWidget);
     a.setMainWidget(moon);
     moon->show();
-    if (argc > 1)
-	moon->calcStatus(time(0) + atoi(argv[1]) * 24 * 60 * 60);
+    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    int offset = args->getOption("offset").toInt();
+    args->clear();
+    if (offset)
+      moon->calcStatus(time(0) + offset * 24 * 60 * 60);
     return a.exec();
 }
