@@ -2,7 +2,7 @@
 #define _TOPLEVEL_H_
 
 
-#include <ktopwidget.h>
+#include <ktmainwindow.h>
 #include <kstatusbar.h>
 
 #include "world.h"
@@ -11,7 +11,7 @@
 const int ID_LOCALTIME = 1;
 
 
-class TopLevel : public KTopLevelWidget
+class TopLevel : public KTMainWindow
 {
   Q_OBJECT;
   
