@@ -65,19 +65,21 @@ void Insets::copy(const Insets& i)
 
 
 
+// #define max(a,b) (a>b?a:b)
+
+
 GridBagConstraints::GridBagConstraints()
-  : RELATIVE(-1)
 {
     gridx = RELATIVE;
     gridy = RELATIVE;
     gridwidth = 1;
     gridheight = 1;
-	
+
     weightx = 0;
     weighty = 0;
     anchor = CENTER;
     fill = NONE;
-    
+
     ipadx = 0;
     ipady = 0;
 
@@ -88,12 +90,12 @@ GridBagConstraints::GridBagConstraints()
     tempHeight=0;
 }
 
-GridBagConstraints::GridBagConstraints(const GridBagConstraints& c)
+GridBagConstraints::GridBagConstraints(GridBagConstraints const& c)
 {
     copy(c);
 }
 
-GridBagConstraints& GridBagConstraints::operator=(const GridBagConstraints& c)
+GridBagConstraints& GridBagConstraints::operator=(GridBagConstraints& c)
 {
     copy(c);
 
@@ -106,23 +108,23 @@ void GridBagConstraints::copy(const GridBagConstraints& c)
     gridy=c.gridy;
     gridwidth=c.gridwidth;
     gridheight=c.gridheight;
-	
+
     weightx=c.weightx;
     weighty=c.weighty;
-	
+
     anchor=c.anchor;
     fill=c.fill;
-	
+
     insets=c.insets;
     ipadx=c.ipadx;
     ipady=c.ipady;
- 
+
     tempX=c.tempX;
     tempY=c.tempY;
-	
+
     tempWidth=c.tempWidth;
     tempHeight=c.tempHeight;
-	
+
     minWidth=c.minWidth;
     minHeight=c.minHeight;
 }
@@ -143,12 +145,12 @@ ostream& operator<<(ostream& out, GridBagLayoutInfo& in)
 {
     out << "Weight: " << in.width << ", " << "Height: " << in.height << endl;
 
-    for(int i=0;i<in.width;i++) 
+    for(int i=0;i<in.width;i++)
 	cout << i << ": " << in.minWidth[i] << ", ";
 
     out << endl;
 
-    for(int i=0;i<in.height;i++) 
+    for(int i=0;i<in.height;i++)
 	out << i << ": " << in.minHeight[i] << ", ";
 
     out << endl;
@@ -160,14 +162,10 @@ ostream& operator<<(ostream& out, GridBagLayoutInfo& in)
  * Creates a gridbag layout.
  */
 GridBagLayout::GridBagLayout(Insets i)
-  : MAXGRIDSIZE(128),
-    MINSIZE(1),
-    PREFERREDSIZE(2)
-
 {
 
     containerInsets=i;
-    
+
     columnWidthsLength=0;
     rowHeightsLength=0;
     columnWeightsLength=0;
@@ -195,7 +193,7 @@ GridBagLayout::~GridBagLayout()
 {
     GridIterator it(comptable);
     GridPair* p;
-    
+
     while(it.current()) {
 
 	p=it.current();
@@ -220,7 +218,7 @@ void GridBagLayout::addLayoutComponent(char* , QWidget*)
 void GridBagLayout::removeLayoutComponent(QWidget* )
 {
 }
-    
+
 /**
      * Sets the constraints for the specified component.
      * @param comp the component to be modified
@@ -241,13 +239,13 @@ GridBagConstraints GridBagLayout::getConstraints(QWidget* comp)
     GridPair* p = comptable.find(comp->name());
 
     GridBagConstraints* constraints=p->second;
-    
+
     if (constraints == NULL) {
-	
+
 	setConstraints(comp, defaultConstraints);
 	return getConstraints(comp);
     }
-	
+
     return GridBagConstraints(*constraints);
 }
 
@@ -262,7 +260,7 @@ GridBagConstraints* GridBagLayout::lookupConstraints(QWidget* comp)
     GridPair* p = comptable.find(comp->name());
 
     GridBagConstraints* constraints=p->second;
-    
+
     if (constraints == NULL)
     {
 	setConstraints(comp, defaultConstraints);
@@ -274,7 +272,7 @@ GridBagConstraints* GridBagLayout::lookupConstraints(QWidget* comp)
 QPoint* GridBagLayout::getLayoutOrigin ()
 {
     QPoint* origin = new QPoint(0,0);
-	
+
     if (layoutInfo != NULL) {
 	origin->setX(layoutInfo->startx);
 	origin->setY(layoutInfo->starty);
@@ -290,7 +288,7 @@ int** GridBagLayout::getLayoutDimensions ()
     int** dim;
 
     dim=(int**)malloc(2*sizeof(int*));
-	
+
     dim[0] = new int[layoutInfo->width];
     dim[1] = new int[layoutInfo->height];
 
@@ -343,26 +341,26 @@ void GridBagLayout::location(int x, int y,QPoint* loc)
 }
 
 
-/** 
+/**
  * Returns the preferred dimensions for this layout given the components
  * in the specified panel.
- * @param parent the component which needs to be laid out 
+ * @param parent the component which needs to be laid out
  * @see #minimumLayoutSize
  */
 void GridBagLayout::preferredLayoutSize(QWidget* parent,QSize* dim)
 {
     GridBagLayoutInfo* info = GetLayoutInfo(parent, PREFERREDSIZE);
     QSize* d=GetMinSize(parent, info);
-    
+
     (*dim)=(*d);
-    
+
     delete info;
 }
 
 /**
- * Returns the minimum dimensions needed to layout the components 
+ * Returns the minimum dimensions needed to layout the components
  * contained in the specified panel.
- * @param parent the component which needs to be laid out 
+ * @param parent the component which needs to be laid out
  * @see #preferredLayoutSize
  */
 void  GridBagLayout::minimumLayoutSize(QWidget* parent,QSize* dim)
@@ -375,8 +373,8 @@ void  GridBagLayout::minimumLayoutSize(QWidget* parent,QSize* dim)
     delete info;
 }
 
-/** 
-     * Lays out the container in the specified panel.  
+/**
+     * Lays out the container in the specified panel.
      * @param parent the specified component being laid out
      * @see Container
      */
@@ -385,7 +383,7 @@ void GridBagLayout::layoutContainer(QWidget* parent)
     ArrangeGrid(parent);
 }
 
-    
+
 /*
  * Fill in an instance of the above structure for the current set
  * of managed children.  This requires three passes through the
@@ -403,7 +401,6 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
     GridBagLayoutInfo* r = new GridBagLayoutInfo();
     QWidget* comp=NULL;;
     GridBagConstraints* constraints=NULL;;
-    QSize* d=NULL;
 
     int i=0, k=0, px=0, py=0, pixels_diff=0, nextSize=0;
     int curX=0, curY=0, curWidth=0, curHeight=0, curRow=0, curCol=0;
@@ -415,26 +412,23 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
      * Figure out the dimensions of the layout grid (use a value of 1 for
      * zero or negative widths and heights).
      */
-    
+
     r->width = r->height = 0;
     curRow = curCol = -1;
-    int* xMax = new int[MAXGRIDSIZE];
-    int* yMax = new int[MAXGRIDSIZE];
-
-//    QObjectList  *list = parent->queryList( "QWidget" );
-//    QObjectListIt it( *list );          // iterate over the buttons
+    int* xMax = new int[(int) MAXGRIDSIZE];
+    int* yMax = new int[(int) MAXGRIDSIZE];
 
     GridIterator it(comptable);
 
     it.toFirst();
-    
+
     while(it.current())
     {
 	GridPair* p=it.current();
-	
+
 	comp = p->first;
 	constraints = p->second;
-      
+
 	curX = constraints->gridx;
 	curY = constraints->gridy;
 	curWidth = constraints->gridwidth;
@@ -443,7 +437,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	curHeight = constraints->gridheight;
 	if (curHeight <= 0)
 	    curHeight = 1;
-      
+
 	/* If x or y is negative, then use relative positioning: */
 	if (curX < 0 && curY < 0) {
 	    if (curRow >= 0)
@@ -456,8 +450,8 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	if (curX < 0) {
 	    px = 0;
 	    for (i = curY; i < (curY + curHeight); i++)
-		px = QMAX(px, xMax[i]);
-	
+		px = max(px, xMax[i]);
+
 	    curX = px - curX - 1;
 	    if(curX < 0)
 		curX = 0;
@@ -465,50 +459,40 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	else if (curY < 0) {
 	    py = 0;
 	    for (i = curX; i < (curX + curWidth); i++)
-		py = QMAX(py, yMax[i]);
-	
+		py = max(py, yMax[i]);
+
 	    curY = py - curY - 1;
 	    if(curY < 0)
 		curY = 0;
 	}
-      
+
 	/* Adjust the grid width and height */
 	for (px = curX + curWidth; r->width < px; r->width++);
 	for (py = curY + curHeight; r->height < py; r->height++);
-      
+
 	/* Adjust the xMax and yMax arrays */
 	for (i = curX; i < (curX + curWidth); i++) { yMax[i] = py; }
 	for (i = curY; i < (curY + curHeight); i++) { xMax[i] = px; }
-      
-	/* Cache the current slave's size. */
-//	if (sizeflag == PREFERREDSIZE)
-//	    d = &comp->maximumSize();
-//	else
 
-	d = &comp->sizeHint();
-//	cout << "preferred For widget: " << comp->name() << ", "
-//	     << d->width() <<"," << d->height() << endl;
-	
-	    
-	constraints->minWidth = d->width();
-	constraints->minHeight = d->height();
-      
+	constraints->minWidth = comp->sizeHint().width();
+	constraints->minHeight = comp->sizeHint().height();
+
 	/* Zero width and height must mean that this is the last item (or
 	 * else something is wrong). */
 	if (constraints->gridheight == 0 && constraints->gridwidth == 0)
 	    curRow = curCol = -1;
-      
+
 	/* Zero width starts a new row */
 	if (constraints->gridheight == 0 && curRow < 0)
 	    curCol = curX + curWidth;
-      
+
 	/* Zero height starts a new column */
 	else if (constraints->gridwidth == 0 && curCol < 0)
 	    curRow = curY + curHeight;
 
 	++it;
     }
-    
+
     /*
      * Apply minimum row/column dimensions
      */
@@ -525,26 +509,26 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
      * Negative or zero values for gridWidth and gridHeight end the current
      *  row or column, respectively.
      */
-    
+
     curRow = curCol = -1;
-    xMax = new int[MAXGRIDSIZE];
-    yMax = new int[MAXGRIDSIZE];
+    xMax = new int[(int) MAXGRIDSIZE];
+    yMax = new int[(int) MAXGRIDSIZE];
 
 
     it.toFirst();
-    
+
     while(it.current())
     {
 	GridPair* p=it.current();
-	
+
 	comp = p->first;
 	constraints = p->second;
-      
+
 	curX = constraints->gridx;
 	curY = constraints->gridy;
 	curWidth = constraints->gridwidth;
 	curHeight = constraints->gridheight;
-      
+
 	/* If x or y is negative, then use relative positioning: */
 	if (curX < 0 && curY < 0) {
 	    if(curRow >= 0)
@@ -554,18 +538,18 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	    else
 		curY = 0;
 	}
-      
+
 	if (curX < 0) {
 	    if (curHeight <= 0) {
 		curHeight += r->height - curY;
 		if (curHeight < 1)
 		    curHeight = 1;
 	    }
-	
+
 	    px = 0;
 	    for (i = curY; i < (curY + curHeight); i++)
-		px = QMAX(px, xMax[i]);
-	
+		px = max(px, xMax[i]);
+
 	    curX = px - curX - 1;
 	    if(curX < 0)
 		curX = 0;
@@ -576,34 +560,34 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 		if (curWidth < 1)
 		    curWidth = 1;
 	    }
-	
+
 	    py = 0;
 	    for (i = curX; i < (curX + curWidth); i++)
-		py = QMAX(py, yMax[i]);
-	
+		py = max(py, yMax[i]);
+
 	    curY = py - curY - 1;
 	    if(curY < 0)
 		curY = 0;
 	}
-      
+
 	if (curWidth <= 0) {
 	    curWidth += r->width - curX;
 	    if (curWidth < 1)
 		curWidth = 1;
 	}
-      
+
 	if (curHeight <= 0) {
 	    curHeight += r->height - curY;
 	    if (curHeight < 1)
 		curHeight = 1;
 	}
-      
+
 	px = curX + curWidth;
 	py = curY + curHeight;
-      
+
 	for (i = curX; i < (curX + curWidth); i++) { yMax[i] = py; }
 	for (i = curY; i < (curY + curHeight); i++) { xMax[i] = px; }
-      
+
 	/* Make negative sizes start a new row/column */
 	if (constraints->gridheight == 0 && constraints->gridwidth == 0)
 	    curRow = curCol = -1;
@@ -611,7 +595,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	    curCol = curX + curWidth;
 	else if (constraints->gridwidth == 0 && curCol < 0)
 	    curRow = curY + curHeight;
-      
+
 	/* Assign the new values to the gridbag slave */
 	constraints->tempX = curX;
 	constraints->tempY = curY;
@@ -620,7 +604,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 
 	++it;
     }
-    
+
     /*
      * Apply minimum row/column dimensions and weights
      */
@@ -638,43 +622,43 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
      *
      * Distribute the minimun widths and weights:
      */
-    
+
     nextSize = MAX_VALUE;
-    
+
     for (i = 1;
 	 i != MAX_VALUE;
 	 i = nextSize, nextSize = MAX_VALUE) {
-	    
+
 	GridIterator it3(comptable);
-	    
+
 	while(it3.current())
 	{
 	    comp = it3.current()->first;
-		
+
 	    constraints = it3.current()->second;
-      
+
 	    if (constraints->tempWidth == i)
 	    {
 		/* right column */
 		px = constraints->tempX + constraints->tempWidth;
-	  
+
 		/* Figure out if we should use this slave\'s
 		 * weight.  If the weight is less than the total
 		 * weight spanned by the width of the cell, then
 		 * discard the weight.  Otherwise split the
 		 * difference according to the existing weights.  */
-	  
+
 		weight_diff = constraints->weightx;
-		    
+
 		for (k = constraints->tempX; k < px; k++)
 		    weight_diff -= r->weightX[k];
-		    
+
 		if (weight_diff > 0.0)
 		{
 		    weight = 0.0;
 		    for (k = constraints->tempX; k < px; k++)
 			weight += r->weightX[k];
-			
+
 		    for (k = constraints->tempX; weight > 0.0 && k < px; k++) {
 			float wt = r->weightX[k];
 			float dx = (wt * weight_diff) / weight;
@@ -685,7 +669,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 		    /* Assign the remainder to the rightmost cell */
 		    r->weightX[px-1] += weight_diff;
 		}
-	  
+
 		/*
 		 * Calculate the minWidth array values.
 		 * First, figure out how wide the current slave needs to be.
@@ -693,7 +677,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 		 * If it will not fit, add the difference according to the
 		 * weightX array.
 		 */
-	  
+
 		pixels_diff =
 		    constraints->minWidth + constraints->ipadx +
 		    constraints->insets.left + constraints->insets.right;
@@ -717,18 +701,18 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 	    }
 	    else if (constraints->tempWidth > i && constraints->tempWidth < nextSize)
 		nextSize = constraints->tempWidth;
-	
-	
+
+
 	    if (constraints->tempHeight == i) {
 		py = constraints->tempY + constraints->tempHeight;
 		/* bottom row */
-	  
+
 		/* Figure out if we should use this slave\'s
 		 * weight.  If the weight is less than the total
 		 * weight spanned by the height of the cell, then
 		 * discard the weight.  Otherwise split it the
 		 * difference according to the existing weights.  */
-	  
+
 		weight_diff = constraints->weighty;
 		for (k = constraints->tempY; k < py; k++)
 		    weight_diff -= r->weightY[k];
@@ -746,7 +730,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 		    /* Assign the remainder to the bottom cell */
 		    r->weightY[py-1] += weight_diff;
 		}
-	  
+
 		/*
 		 * Calculate the minHeight array values.
 		 * First, figure out how tall the current slave needs to be.
@@ -754,7 +738,7 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 		 * If it will not fit, add the difference according to the
 		 * weightY array.
 		 */
-	  
+
 		pixels_diff =
 		    constraints->minHeight + constraints->ipady +
 		    constraints->insets.top + constraints->insets.bottom;
@@ -781,15 +765,15 @@ GridBagLayoutInfo* GridBagLayout::GetLayoutInfo(QWidget* , int)
 
 	    ++it3;
 	}
-	    
+
     }
 
     delete yMax;
     delete xMax;
-    
+
     return r;
 }
-  
+
 /*
      * Adjusts the x, y, width, and height fields to the correct
      * values depending on the constraint geometry and pads.
@@ -801,10 +785,10 @@ void GridBagLayout::AdjustForGravity(GridBagConstraints* constraints,
 
     r.x += constraints->insets.left;
     r.width -=(constraints->insets.left + constraints->insets.right);
-	
+
     r.y += constraints->insets.top;
     r.height -= (constraints->insets.top + constraints->insets.bottom);
-    
+
     diffx = 0;
     if ((constraints->fill != GridBagConstraints::HORIZONTAL &&
 	 constraints->fill != GridBagConstraints::BOTH)
@@ -812,7 +796,7 @@ void GridBagLayout::AdjustForGravity(GridBagConstraints* constraints,
 	diffx = r.width - (constraints->minWidth + constraints->ipadx);
 	r.width = constraints->minWidth + constraints->ipadx;
     }
-    
+
     diffy = 0;
     if ((constraints->fill != GridBagConstraints::VERTICAL &&
 	 constraints->fill != GridBagConstraints::BOTH)
@@ -820,7 +804,7 @@ void GridBagLayout::AdjustForGravity(GridBagConstraints* constraints,
 	diffy = r.height - (constraints->minHeight + constraints->ipady);
 	r.height = constraints->minHeight + constraints->ipady;
     }
-    
+
     switch (constraints->anchor) {
     case GridBagConstraints::CENTER:
 	r.x += diffx/2;
@@ -865,7 +849,7 @@ QSize* GridBagLayout::GetMinSize(QWidget*, GridBagLayoutInfo* info)
 {
     QSize* d = new QSize();
     int i, t;
-    
+
 
     t = 0;
     for(i = 0; i < info->width; i++)
@@ -893,7 +877,7 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
     int i=0, diffw=0, diffh=0;
     float weight=0;
     GridBagLayoutInfo* info;
-    
+
     /*
      * If the parent has no slaves anymore, then don't do anything
      * at all:  just leave the parent's size as-is.
@@ -903,12 +887,12 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
 	(rowHeights == NULL || rowHeightsLength == 0)) {
 	return;
     }
-    
+
     /*
      * Pass #1: scan all the slaves to figure out the total amount
      * of space needed.
      */
-    
+
     info = GetLayoutInfo(parent, PREFERREDSIZE);
     d = GetMinSize(parent, info);
 
@@ -922,13 +906,13 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
     r.width=d->width();
     r.height=d->height();
 
-    
+
     /*
      * If the current dimensions of the window don't match the desired
      * dimensions, then adjust the minWidth and minHeight arrays
      * according to the weights.
      */
-    
+
     diffw = parent->width() - r.width;
     if (diffw != 0) {
 	weight = 0.0;
@@ -950,7 +934,7 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
     else {
 	diffw = 0;
     }
-    
+
     diffh = parent->height() - r.height;
     if (diffh != 0) {
 	weight = 0.0;
@@ -979,29 +963,29 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
      * System.out.println("Re-adjusted:");
      * DumpLayoutInfo(info);
      */
-    
+
     /*
      * Now do the actual layout of the slaves using the layout information
      * that has been collected.
      */
-    
+
     info->startx = diffw/2 + insets.left;
     info->starty = diffh/2 + insets.top;
 
-    
+
     // Tranverse over the managed children
-    GridIterator it2( comptable );          
-	
+    GridIterator it2( comptable );
+
     while(it2.current()) {
-	
+
 	comp = it2.current()->first;
 	constraints = it2.current()->second;
 
 	r.x=info->startx;
 	for(i = 0; i < constraints->tempX; i++)
 	   r.x += info->minWidth[i];
-	
-      
+
+
 	r.y = info->starty;
 	for(i = 0; i < constraints->tempY; i++)
 	    r.y +=info->minHeight[i];
@@ -1013,31 +997,31 @@ void GridBagLayout::ArrangeGrid(QWidget* parent)
 	    r.width += info->minWidth[i];
 	}
 
-      
+
 	r.height = 0;
 	for(i = constraints->tempY;
 	    i < (constraints->tempY + constraints->tempHeight);
 	    i++) {
 	    r.height += info->minHeight[i];
 	}
-      
+
 	AdjustForGravity(constraints, r);
-      
+
 	/*
 	 * If the window is too small to be interesting then
 	 * unmap it.  Otherwise configure it and then make sure
 	 * it's mapped.
 	 */
-      
+
 	if ((r.width <= 0) || (r.height <= 0)) {
-	    
+
 	    comp->setGeometry(0, 0, 0, 0);
 	}
 	else {
-	    
+
 	    if (comp->x() != r.x || comp->y() != r.y ||
 		comp->width() != r.width || comp->height() != r.height) {
-		
+
 		comp->setGeometry(r.x, r.y, r.width, r.height);
 	    }
 	}
@@ -1062,7 +1046,7 @@ GridBagLayoutInfo* GridBagLayout::getGridInfo(QWidget* parent)
     int i=0, diffw=0, diffh=0;
     float weight=0;
     GridBagLayoutInfo* info;
-    
+
     /*
      * If the parent has no slaves anymore, then don't do anything
      * at all:  just leave the parent's size as-is.
@@ -1072,12 +1056,12 @@ GridBagLayoutInfo* GridBagLayout::getGridInfo(QWidget* parent)
 	(rowHeights == NULL || rowHeightsLength == 0)) {
 	return NULL;
     }
-    
+
     /*
      * Pass #1: scan all the slaves to figure out the total amount
      * of space needed.
      */
-    
+
     info = GetLayoutInfo(parent, PREFERREDSIZE);
     d = GetMinSize(parent, info);
 
@@ -1091,13 +1075,13 @@ GridBagLayoutInfo* GridBagLayout::getGridInfo(QWidget* parent)
     r.width=d->width();
     r.height=d->height();
 
-    
+
     /*
      * If the current dimensions of the window don't match the desired
      * dimensions, then adjust the minWidth and minHeight arrays
      * according to the weights.
      */
-    
+
     diffw = parent->width() - r.width;
     if (diffw != 0) {
 	weight = 0.0;
@@ -1119,7 +1103,7 @@ GridBagLayoutInfo* GridBagLayout::getGridInfo(QWidget* parent)
     else {
 	diffw = 0;
     }
-    
+
     diffh = parent->height() - r.height;
     if (diffh != 0) {
 	weight = 0.0;
