@@ -29,7 +29,7 @@ public:
 class Rectangle
 {
 public:
-    
+
     int x;
     int y;
     int width;
@@ -43,7 +43,7 @@ class Insets
 {
 
 public:
- 
+
     /// The inset from the top.
     int top;
 
@@ -84,67 +84,66 @@ public:
 
 
 
+#define max(a,b) ((a)>(b)?(a):(b))
+
 class GridBagConstraints
 {
 public:
- 
-    const int RELATIVE;
 
-    enum { NONE = 0, BOTH, HORIZONTAL, VERTICAL };
- 	   
-    enum { CENTER = 10, NORTH, NORTHEAST, EAST, SOUTHEAST,
-	   SOUTH, SOUTHWEST, WEST, NORTHWEST };
- 
+    enum { RELATIVE = -1, REMAINDER = 0, NONE = 0, BOTH = 1, HORIZONTAL = 2,
+    VERTICAL = 3, CENTER = 10, NORTH = 11, NORTHEAST = 12, EAST = 13,
+    SOUTHEAST = 14, SOUTH = 15, SOUTHWEST = 16, WEST = 17, NORTHWEST = 18 };
+
     int gridx, gridy, gridwidth, gridheight;
     float weightx, weighty;
     int anchor, fill;
     Insets insets;
     int ipadx, ipady;
- 
+
     int tempX, tempY;
     int tempWidth, tempHeight;
     int minWidth, minHeight;
 
     GridBagConstraints();
- 
+
     GridBagConstraints(const GridBagConstraints& c);
 
     void copy(const GridBagConstraints& c);
 
-    GridBagConstraints& operator=(const GridBagConstraints& c);
+    GridBagConstraints& operator=(GridBagConstraints& c);
 };
 
 
 class GridBagLayoutInfo
 {
 public:
- 
+
     int width, height;		/* number of cells horizontally, vertically */
     int startx, starty;		/* starting point for layout */
     int* minWidth;		/* largest minWidth in each column */
     int* minHeight;		/* largest minHeight in each row */
     float* weightX;		/* largest weight in each column */
     float* weightY;		/* largest weight in each row */
- 
+
     GridBagLayoutInfo()
     {
-	int MAXGRIDSIZE=128;
+	const int MAXGRIDSIZE = 128;
 
 	width=0;
 	height=0;
 	startx=0;
 	starty=0;
-	
-	
+
+
 	minWidth = new int[MAXGRIDSIZE];
 	memset(minWidth,0,sizeof(int)*MAXGRIDSIZE);
-	
+
 	minHeight = new int[MAXGRIDSIZE];
 	memset(minHeight,0,sizeof(int)*MAXGRIDSIZE);
-	
+
 	weightX = new float[MAXGRIDSIZE];
 	memset(weightX,0,sizeof(int)*MAXGRIDSIZE);
-	
+
 	weightY = new float[MAXGRIDSIZE];
 	memset(weightY,0,sizeof(int)*MAXGRIDSIZE);
     }
@@ -163,7 +162,7 @@ class GridBagLayout : QObject
 {
     Q_OBJECT
 public:
-    
+
     /**
      * Creates a gridbag layout.
      */
@@ -180,11 +179,11 @@ public:
     GridBagLayout(Insets i);
 
     void setInsets(Insets i);
-    
+
     void addLayoutComponent(char* , QWidget*);
 
     void removeLayoutComponent(QWidget* );
-    
+
     /**
      * Sets the constraints for the specified component.
      * @param comp the component to be modified
@@ -199,38 +198,36 @@ public:
      */
     GridBagConstraints getConstraints(QWidget* comp);
 
-    
-    /** 
+
+    /**
      * Returns the preferred dimensions for this layout given the components
      * in the specified panel.
-     * @param parent the component which needs to be laid out 
+     * @param parent the component which needs to be laid out
      * @see #minimumLayoutSize
      */
      void preferredLayoutSize(QWidget* parent,QSize* dim);
-    
+
     /**
-     * Returns the minimum dimensions needed to layout the components 
+     * Returns the minimum dimensions needed to layout the components
      * contained in the specified panel.
-     * @param parent the component which needs to be laid out 
+     * @param parent the component which needs to be laid out
      * @see #preferredLayoutSize
      */
     void minimumLayoutSize(QWidget* parent,QSize* dim);
-    
-    /** 
-     * Lays out the container in the specified panel.  
+
+    /**
+     * Lays out the container in the specified panel.
      * @param parent the specified component being laid out
      * @see Container
      */
     void layoutContainer(QWidget* parent);
-    
+
 //protected:
- 
-    const int MAXGRIDSIZE;
-    const int MINSIZE;
-    const int PREFERREDSIZE;
+
+    enum { MINSIZE = 1, PREFERREDSIZE = 2, MAXGRIDSIZE = 128 };
 
     QDict<GridPair > comptable;
- 
+
     GridBagConstraints defaultConstraints;
     GridBagLayoutInfo* layoutInfo;
 
@@ -275,7 +272,7 @@ public:
      */
 
     GridBagLayoutInfo* GetLayoutInfo(QWidget* parent, int sizeflag);
-  
+
     /*
      * Adjusts the x, y, width, and height fields to the correct
      * values depending on the constraint geometry and pads.
