@@ -103,14 +103,24 @@
 #include <qmessagebox.h>
 
 #include <kapp.h>
+#include <kconfig.h>
 #include <kwm.h>
-#include <ktopwidget.h>
+#include <ktmainwindow.h>
 #include <ktoolbar.h>
 #include <kiconloader.h>
-
+#include <kstddirs.h>
+#include <klocale.h>
+#include <kaboutdata.h>
+#include <kcmdlineargs.h>
 
 #include "kodo.h"
 
+static	struct conversionEntry ConversionTable[MAX_UNIT] = {
+{ inch, "inch", "inches", 12.0,   2.54,     "cm",     "cm",     100.0,  3 },
+{ foot, "foot", "feet",   5280.0, 0.3048,    "meter", "meters", 1000.0, 4 },
+{ mile, "mile", "miles",  -1.0,   1.609344, "km",     "km",     -1.0,   5 }
+};
+
 // My port of java's gridbaglayout.  Overkill here, but I need test-cases.
 #include "gridbag.h"
 
@@ -121,14 +131,11 @@
  * to make clicks on them bring up the context-menu.
  */
 Kodometer::Kodometer(QWidget* parent,const char* name)
-    : AnPanel(parent,name),
-      speedInterval(500.0),
-      distanceInterval(10.0),
-      speedSamples(10)
+    : AnPanel(parent,name)
 {
     debug        = 0;
 
-    display=KApplication::getKApplication()->getDisplay();
+    display=KApplication::kApplication()->getDisplay();
     FindAllScreens();
 
     root = RootWindow(display,DefaultScreen(display));
@@ -159,14 +166,9 @@ Kodometer::Kodometer(QWidget* parent,const char* name)
 
     readSettings();
 
-
-    QString libDir;
-    libDir.setStr(KApplication::kde_datadir().copy());
-    libDir.append("/kodo/");
-
-    
-    totalLabel=new KImageNumber(libDir+"57-2.gif",this,"Total");    
-    tripLabel=new KImageNumber(libDir+"57-2.gif",this,"Trip");
+    totalLabel=new KImageNumber(locate("appdata", "57-2.gif"),
+				this,"Total");    
+    tripLabel=new KImageNumber(locate("appdata", "57-2.gif"),this,"Trip");
 //    speedLabel=new KImageNumber(libDir+"57-2.gif",this,"Speed");
 
 
@@ -308,7 +310,7 @@ void Kodometer::FindAllScreens(void)
  */
 bool Kodometer::eventFilter( QObject *, QEvent *e )
 {
-    if ( e->type() == Event_MouseButtonPress ) {
+    if ( e->type() == QEvent::MouseButtonPress ) {
 	mousePressEvent((QMouseEvent*)e);
 	return TRUE;                        
     }
@@ -551,11 +553,13 @@ int Kodometer::CalcDistance(void)
     double distMM, distInches, finalNewDist;
     double oldDistance, oldTripDistance;
     double newDistance, newTripDistance;
-    int i = 0, j, finalScreen, increment;
+    int i, j, finalScreen, increment;
     Units oldDistanceUnit, oldTripDistanceUnit, currentUnit;
     int distanceChanged, tripDistanceChanged;
 
     int screenOrientation=K_Left;
+
+    i = j = finalScreen = increment = 0;
     
     if (lastXCoord == 0 && lastYCoord == 0)
 	return FALSE;
@@ -727,7 +731,7 @@ int Kodometer::CalcDistance(void)
 void Kodometer::FormatDistance(double in_dist, Units unit,QString& string)
 {
     double out_dist = in_dist;
-    char *tag;
+    const char *tag;
     int precision;
 
     if (UseMetric)
@@ -763,7 +767,7 @@ void Kodometer::FormatDistance(double in_dist, Units unit,QString& string)
  */
 void Kodometer::readSettings(void)
 {
-    KConfig *config = KApplication::getKApplication()->getConfig();
+    KConfig *config = KApplication::kApplication()->config();
     config->setGroup( "Settings" );
 
     UseMetric = config->readNumEntry("UseMetric");
@@ -796,7 +800,7 @@ void Kodometer::readSettings(void)
  */
 void Kodometer::saveSettings(void)
 {
-    KConfig *config = KApplication::getKApplication()->getConfig();
+    KConfig *config = KApplication::kApplication()->config();
     config->setGroup( "Settings" );
     
     QString str;
@@ -818,7 +822,7 @@ void Kodometer::saveSettings(void)
 // Callback to display help
 void Kodometer::help()
 {
-    KApplication::getKApplication()->invokeHTMLHelp( "" , "" );
+    KApplication::kApplication()->invokeHTMLHelp( "" , "" );
 }
 
 
@@ -899,22 +903,30 @@ void Kodometer::about()
 */
 
     
-    QMessageBox::about( this, "About Mouspedometa",
-			"Mouspedometa measures your desktop mileage.\n"
+    QMessageBox::about( this, i18n("About Mouspedometa"),
+			i18n("Mouspedometa measures your desktop mileage.\n"
 			"Copyright 1998 Armen Nakashian\n\n"
 			"This program is free, do with it what you will.\n"
 			"This program is part of the K Desktop Environment.\n\n"
-			"http://yawara.anime.net/kodo/\n\n");
+			"http://yawara.anime.net/kodo/\n\n"));
 }
 
+static const char* description=I18N_NOOP("Mouspedometa measures your desktop mileage");
+
 int main(int argc,char **argv)
 {
     
     /* Top level details */
 
-    KApplication a(argc,argv);
+    KAboutData aboutData("kodo", I18N_NOOP("Mouspedometa"),
+        VERSION, description, KAboutData::License_GPL,
+        "(c) 1998, Armen Nakashian");
+    aboutData.addAuthor("Armen Nakashian",0, 0,"http://yawara.anime.net/kodo/");
+    KCmdLineArgs::init( argc, argv, &aboutData );
+    
+    KApplication a;
     // We need a top-level widget for the GridBag panel.
-    KTopLevelWidget w;
+    KTMainWindow w;
     
     Kodometer o(&w,"Kodo");
 
@@ -923,8 +935,11 @@ int main(int argc,char **argv)
     a.setMainWidget(&w);
 
     // session management!
+#warning fix session management
+#if 0    
     a.enableSessionManagement(true);
-    a.setWmCommand(argv[0]);      
+    a.setWmCommand(argv[0]);
+#endif    
     a.setTopWidget(&w);
 
     
