@@ -4,7 +4,8 @@
 
 #include <qlabel.h>
 #include <qlist.h>
-#include <qpopmenu.h>
+#include <qpopupmenu.h>
+#include <qapplication.h>
 
 #include <X11/Xlib.h>
 
@@ -38,23 +39,16 @@ typedef struct
 
 typedef struct conversionEntry {
     Units fromUnit;
-    char *fromUnitTag;
-    char *fromUnitTagPlural;
+    const char *fromUnitTag;
+    const char *fromUnitTagPlural;
     double maxFromBeforeNext;
     double conversionFactor;
-    char *toUnitTag;
-    char *toUnitTagPlural;
+    const char *toUnitTag;
+    const char *toUnitTagPlural;
     double maxToBeforeNext;
     int printPrecision;
 } conversionEntry;
 
-static	struct conversionEntry ConversionTable[MAX_UNIT] = {
-{ inch, "inch", "inches", 12.0,   2.54,     "cm",     "cm",     100.0,  3 },
-{ foot, "foot", "feet",   5280.0, 0.3048,    "meter", "meters", 1000.0, 4 },
-{ mile, "mile", "miles",  -1.0,   1.609344, "km",     "km",     -1.0,   5 }
-};
-
-
 class AnPanel : public QFrame
 {
     Q_OBJECT
@@ -75,10 +69,10 @@ public:
     virtual void setConstraints(QWidget* w,GridBagConstraints& gc) {
 	gb->setConstraints(w,gc);
     }
-    
+
     virtual void resizeEvent(QResizeEvent* r) {
 	QWidget::resizeEvent(r);
-	
+
 	if(ignoreResize==0)
 	    gb->layoutContainer(this);
     }
@@ -90,25 +84,24 @@ public:
 	gb->preferredLayoutSize(this,&s);
 	return s;
     }
-    
+
 protected:
-    
+
     GridBagLayout* gb;
     int ignoreResize;
 };
 
 
 
+const double speedInterval=500.0;
+const double distanceInterval=10.0;
+const int speedSamples=10;
 
 class Kodometer : public AnPanel
 {
     Q_OBJECT
-public:
 
-    const double speedInterval;
-    const double distanceInterval;
-    const int speedSamples;
-    
+public:
     Kodometer(QWidget* ,const char* );
     ~Kodometer() {}
     void refresh(void);
@@ -119,9 +112,9 @@ public:
     void mousePressEvent(QMouseEvent*);
 //    void paintEvent( QPaintEvent * );
     bool eventFilter( QObject *, QEvent *e );
-    
+
 public slots:
-     
+
     void toggleEnabled();
     void toggleUnits();
     void toggleAutoReset();
@@ -130,7 +123,7 @@ public slots:
     void quit();
     void help();
     void about();
-    
+
 protected:
 
     double multiplier(Units);
@@ -162,7 +155,7 @@ protected:
     int lastXCoord, lastYCoord;
 
     Units lastDUnit, lastTUnit;
-    
+
     int pointerScreen, lastPointerScreen;
     int Enabled;
     int UseMetric;
@@ -177,7 +170,7 @@ protected:
 
     _screenInfo screenInfo[MAX_SCREEN];
     int screenCount;
-    
+
 };
 
 #endif
