@@ -8,13 +8,13 @@
     pixmap = loader->loadIcon("filenew2.xpm");
     toolbar->insertButton(pixmap, 0,
 			  SIGNAL(clicked()), &o,
-			  SLOT(help()), TRUE, klocale->translate("New Document"));
+			  SLOT(help()), TRUE, i18n("New Document"));
     
     
     pixmap = loader->loadIcon("fileopen.xpm");
     toolbar->insertButton(pixmap, 0,
 			  SIGNAL(clicked()), &o,
-			  SLOT(help()), TRUE, klocale->translate("Open Document"));
+			  SLOT(help()), TRUE, i18n("Open Document"));
 
     toolbar->setMaxWidth(100);
     w.addToolBar(toolbar);
@@ -25,13 +25,13 @@
     pixmap = loader->loadIcon("filenew2.xpm");
     toolbar->insertButton(pixmap, 0,
 			  SIGNAL(clicked()), &o,
-			  SLOT(help()), TRUE, klocale->translate("gash"));
+			  SLOT(help()), TRUE, i18n("gash"));
     
     
     pixmap = loader->loadIcon("fileopen.xpm");
     toolbar->insertButton(pixmap, 0,
 			  SIGNAL(clicked()), &o,
-			  SLOT(help()), TRUE, klocale->translate("Goosh"));
+			  SLOT(help()), TRUE, i18n("Goosh"));
 
     toolbar->setMaxWidth(150);
     w.addToolBar(toolbar);
